==> Paws-0.30.tar.gz: Paws-0.30/lib/Paws/ELBv2/LoadBalancerState.pm <==
package Paws::ELBv2::LoadBalancerState;
  use Moose;
  has Code => (is => 'ro', isa => 'Str');
  has Reason => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::ELBv2::LoadBalancerState

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::ELBv2::LoadBalancerState object:

  $service_obj->Method(Att1 => { Code => $value, ..., Reason => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::ELBv2::LoadBalancerState object:

  $result = $service_obj->Method(...);
  $result->Att1->Code

=head1 DESCRIPTION

Information about the state of the load balancer.

=head1 ATTRIBUTES


=head2 Code => Str

  The state code. The initial state of the load balancer is
C<provisioning>. After the load balancer is fully set up and ready to
route traffic, its state is C<active>. If the load balancer could not
be set up, its state is C<failed>.


=head2 Reason => Str

  A description of the state.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::ELBv2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.37.tar.gz: Paws-0.37/lib/Paws/ELBv2/LoadBalancerState.pm <==
package Paws::ELBv2::LoadBalancerState;
  use Moose;
  has Code => (is => 'ro', isa => 'Str');
  has Reason => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::ELBv2::LoadBalancerState

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::ELBv2::LoadBalancerState object:

  $service_obj->Method(Att1 => { Code => $value, ..., Reason => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::ELBv2::LoadBalancerState object:

  $result = $service_obj->Method(...);
  $result->Att1->Code

=head1 DESCRIPTION

Information about the state of the load balancer.

=head1 ATTRIBUTES


=head2 Code => Str

  The state code. The initial state of the load balancer is
C<provisioning>. After the load balancer is fully set up and ready to
route traffic, its state is C<active>. If the load balancer could not
be set up, its state is C<failed>.


=head2 Reason => Str

  A description of the state.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::ELBv2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
